#
# spec file for package python-WTForms
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-WTForms
Version:        2.0.2
Release:        4.1
Url:            http://wtforms.simplecodes.com/
Summary:        A flexible forms validation and rendering library for Python web development
License:        BSD-3-Clause
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/W/WTForms/WTForms-%{version}.zip
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fdupes
BuildRequires:  python-devel
BuildRequires:  python-setuptools
BuildRequires:  unzip

%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
BuildRequires:  python-ordereddict
Requires:       python-ordereddict
Recommends:     python-django
Recommends:     python-google-appengine
Recommends:     python-SQLAlchemy
%else
BuildArch:      noarch
%endif

%description
WTForms is a forms validation and rendering library for Python web development.
With WTForms, your form field HTML can be generated for you, but we let you customize it in your templates. 
This allows you to maintain separation of code and presentation, and keep those messy parameters out of your python code. 
Because we strive for loose coupling, you should be able to do that in any templating engine you like, as well.

%package doc
Summary:        Documentation for WTForms
Group:          Documentation/HTML
Requires:       %{name} = %{version}

%description doc
Documentation of WTForms is a forms validation and rendering library for Python web development.

%package lang
Summary:        Languages for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Provides:       %{name}-lang-all = %{version}
Supplements:    packageand(bundle-lang-other:%{name})

%description lang
Provides translations to the package %{name}

%prep
%setup -q -n WTForms-%{version}
sed -i "s/\r//" CHANGES.rst docs/html/_static/jquery.js # Fix wrong EOL-encoding
rm -rf docs/html/.buildinfo # Remove junk

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
%find_lang wtforms
%fdupes %{buildroot}%{_prefix}

%check
python setup.py -q test

%files doc
%defattr(-,root,root,-)
%doc docs/html

%files lang -f wtforms.lang
%defattr(-,root,root,-)
%{python_sitelib}/wtforms/locale

%files
%defattr(-,root,root,-)
%exclude %{python_sitelib}/wtforms/locale
%{python_sitelib}/*
%doc AUTHORS.txt CHANGES.rst LICENSE.txt README.md

%changelog
* Thu May 14 2015 benoit.monin@gmx.fr
- update to version 2.0.2:
  * Added more localizations and updated some
  * Validators for email and URL can validate IDNA-encoded domain
    names and new TLDs
  * Better DeprecationWarnings
  * Support localization files in /usr/share/locale (for distro
    packaging)
- additional changes from version 2.0.1
  * Released July 1, 2014
  * Update wheel install to conditionally install ordereddict for
    python 2.6
  * Doc improvements
- additional changes from version 2.0
  * Add new class Meta paradigm for much more powerful
    customization of WTForms
  * Move i18n into core. Deprecate wtforms.ext.i18n
  * Move CSRF into core. Deprecate wtforms.ext.csrf
  * Fix issue rendering SelectFields with value=True
  * Make DecimalField able to use babel locale-based number
    formatting
  * Drop Python 3.2 support (Python3 support for 3.3+ only)
  * passing attr=False to WTForms widgets causes the value to be
    ignored
  * Unique validator in wtforms.ext.sqlalchemy has been removed
- add new dependency python-ordereddict for SLE11
- update the list of files to fix end of line encoding
- use %%find_lang for the lang subpackage: paths changed upstream
- run the tests during build
- rename CHANGES.txt to CHANGES.rst: changed upstream
- rename README.txt to README.md: changed upstream
* Thu Apr 10 2014 aboe76@gmail.com
- Updated to version 1.0.5:
  + Fix a bug in validators which causes translations to happen once then clobber any future translations.
  + ext.sqlalchemy / ext.appengine: minor cleanups / deprecation.
  + Allow blank string and the string 'false' to be considered false values for BooleanField (configurable). This is technically a breaking change, but it is not likey to affect the majority of users adversely.
  + ext.i18n form allows passing LANGUAGES to the constructor.
- from version 1.0.4:
  + Add widgets and field implementations for HTML5 specialty input types.
  + ext.appengine: Add NDB support.
  + Add translations: Korean, Traditional Chinese
- cleaned up spec file:
  + created a doc package
  + rpmlint lang warnings script taken from python-wxWidgets
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sun Apr 14 2013 p.drouand@gmail.com
- Update to version 1.0.3
  + Tests complete in python 3.2/3.3.
  + Localization for ru, fr.
  + Minor fixes in documentation for clarity.
  + FieldList now can take validators on the entire FieldList.
  + ext.sqlalchemy model_form:
  * Fix issue with QuerySelectField
  * Fix issue in ColumnDefault conversion
  * Support Enum type
  + Field class now allows traversal in Django 1.4 templates.
- Initial python3 support
* Tue Sep 27 2011 saschpe@suse.de
- Update to version 0.6.3:
  * Documentation: Substantial documentation improvements, including adding
    Crash Course as a sphinx document.
  * ext.django: QuerySetSelectField (and ModelSelectField) now accept get_label
    similar to sqlalchemy equivalents.
  * ext.appengine:
    + model_form fixes: FloatField(#50), TimeField, DateTimeField(#55)
    + ReferencePropertyField: now properly stores model object, not key. (#48)
- Changes from version 0.6.2:
  * ext.appengine: various field fixes (#34, #48), model_form changes (#41)
  * Fix issue in Optional with non-string input.
  * Make numeric fields more consistent.
  * Tests: Improve test coverage substantially.
- Recommend python-django, python-SQLAlchemy & python-google-appengine,
  WTForms provides optional integration for each
- Package documentation
* Tue Oct 26 2010 kianseong@gmail.com
- Further changes to spec based on review
* Tue Oct 26 2010 kianseong@gmail.com
- Changes to spec file based on review
* Tue Oct 26 2010 kianseong@gmail.com
- New package wtforms
